<?php

namespace Drupal\pmfs\EventSubscriber;

use Drupal\Component\Utility\Crypt;
use Drupal\pmfs\Pmfs;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class Cookie.
 *
 * @package Drupal\pmfs\EventSubscriber
 */
class Cookie implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      'kernel.request' => 'setCookie',
    ];
  }

  /**
   * Cookie handler of the module.
   *
   * @param \Symfony\Component\HttpKernel\Event\GetResponseEvent|\Symfony\Component\HttpKernel\Event\RequestEvent $event
   *   Request event.
   */
  public function setCookie($event) {
    $request = $event->getRequest();
    if (!$request->cookies->get(Pmfs::COOKIE)) {
      if (PHP_VERSION_ID >= 70300) {
        setcookie(Pmfs::COOKIE, Crypt::hashBase64(implode(',', array_merge($request->getClientIps(), [\time()]))), ['path' => '/']);
      }
      else {
        setcookie(Pmfs::COOKIE, Crypt::hashBase64(implode(',', array_merge($request->getClientIps(), [\time()]))), 0, '/');
      }
    }
  }

}
